package uk.ac.cf.spring.demo.sports.rankingtable;

import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class RankingServiceImpl implements RankingService {
    private final RankingRepository rankingRepository;

    public RankingServiceImpl(RankingRepository rankingRepository) {
        this.rankingRepository = rankingRepository;
    }


    @Override
    public List<RankingTable> getAllRankings() {
        return rankingRepository.findAll();
    }


    @Override
    public List<RankingTable> getRankingsBySport(String sport) {
        return rankingRepository.findBySport(sport);
    }


    @Override
    public void updateRanking(Long userId, String sport, int wins) {
        rankingRepository.saveOrUpdate(userId, sport, wins);
    }


    @Override
    public void processCompletedMatches() {

        List<RankingRepository.MatchResult> completedMatches = rankingRepository.findWinnersAndSportsFromCompletedMatches();

        // loop every match result
        for (RankingRepository.MatchResult result : completedMatches) {
            Long winnerId = result.getWinnerId();
            String sport = result.getSport();

            // current user wins in particular sport
            RankingTable currentRanking = rankingRepository.findByUserIdAndSport(winnerId, sport);
            int currentWins = currentRanking != null ? currentRanking.getWins() : 0;

            // update
            rankingRepository.saveOrUpdate(winnerId, sport, currentWins + 1);
        }
    }
    @Override
    public List<RankingTable> getAllRankingsSortedByWins(String order) {
        return rankingRepository.findAllSortedByWins(order);
    }

    @Override
    public List<RankingTable> getRankingsBySportAndOrder(String sport, String order) {
        if (sport == null || sport.equalsIgnoreCase("all")) {
            // 如果没有选择特定运动，则按总胜利数排序
            return rankingRepository.findAllSortedByWins(order);
        } else {
            // 按特定运动和排序方式筛选
            return rankingRepository.findBySportAndOrder(sport, order);
        }
    }
    public List<TotalWinsDTO> getTotalWinsByAll(String order) {
        return rankingRepository.findTotalWinsByAll(order);
    }

}

